#!/usr/bin/env python
# -*- coding: utf-8 -*-

##
# How to use Miriade webservice using SOAP protocol
# =================================================
#
# This example requires the SOAPpy library : https://pypi.python.org/pypi/SOAPpy/
#
#
#
# 2013 by F. Noctulle (IMCCE/OBSPM) <fnoctulle@imcce.fr>
#

from SOAPpy import WSDL, headerType, Error

# Webservice configuration
# ------------------------
# Miriade webservice handles WSDL

wsdl_url = 'http://vo.imcce.fr/webservices/miriade/miriade.php?wsdl'

# You have to set the SOAP header
# Fill in either the from field or your Host IP
hdr_config = {'clientID': {'from': 'Miriade.python', 'hostip': ''}}

# SOAP client instanciation
# -------------------------
soap_client = WSDL.Proxy(wsdl_url, header=headerType(hdr_config))

# Webservice usage
# ----------------
request_data = {
        'name': 'a:ceres',
        'type': '',
        'epoch': 'now',
        'nbd': 5,
        'step': '1d',
        'tscale': 'UTC',
        'observer': '500',
        'theory': 'INPOP',
        'teph': 1,
        'tcoor': 1,
        'rplane': 1,
        'mime': 'text',
        'output': '',
        'extrap': 0,
    }

# Method call
# -----------
try:
    result = soap_client.ephemcc(request_data)

    print("Flag : {}".format(result['flag']))
    print("Ticket : {}".format(result['ticket']))
    print("Result : ")
    res = result['result'].split(';')
    for r in res:
        print(r)
except Error as err:
    print(err)
